@@ -1,7 +1,7 @@
 package Carmel;
 use strict;
 use 5.012000;
-use version; our $VERSION = version->declare('v0.1.44');
+use version; our $VERSION = version->declare('v0.1.45');
 
 1;
 __END__
@@ -73,7 +73,16 @@ containers.
 
 =head1 WORKFLOW
 
-Here's a typical workflow of using Carmel.
+=head2 Development
+
+During the development, run C<carmel install> when you setup a new environment,
+and any time you make changes to C<cpanfile>. This will update your build
+artifacts, and saves the changes to C<cpanfile.snapshot>. Commit the snapshot
+file in version control system so that you can reproduce the exact same versions
+across machines.
+
+C<carmel exec> makes it easy to run your application using the versions in
+C<cpanfile> and C<cpanfile.snapshot> dynamically.
 
   # On your development environment
   > cat cpanfile
@@ -98,10 +107,42 @@ Here's a typical workflow of using Carmel.
   # Update Plack to the latest
   > carmel update Plack
 
+=head2 Production Deployments
+
+Carmel allows you to manage all the dependencies the same way across development
+environments and production environments. However, there might be cases where
+you want to avoid running your application with C<carmel exec> in production, to
+avoid the overhead with large number of include paths, or to avoid installing
+Carmel in the production hosts.
+
+Carmel provides two easy ways to avoid depending on Carmel on the deploy target
+environments. First, C<carmel rollout> rolls out the build artifacts into a
+regular perl5 library path in C<local>. Once the rollout is complete, you can
+include the path just like a regular L<local::lib> directory.
+
   # Production environment: Roll out to ./local
   > carmel rollout
   > perl -Ilocal/lib/perl5 local/bin/starman -p 8080 myapp.psgi
 
+You can run C<carmel rollout>> in a CI system to create the C<local> directory
+next to your application code for a linux package (e.g. deb package), or Docker
+containers.
+
+Second, C<carmel package> (similar to C<carton bundle>) creates a directory with
+tarballs and CPAN-style package index files, which you can pass to L<cpanm> on a
+target machine. This way, you only need C<cpanm>, which is available as a
+self-contained single executable, to bootstrap the installation on a host with a
+stock perl.
+
+  # Vendor all the packages to vendor/cache
+  > carmel package
+  > git add vendor/cache
+  > git commit -m 'Vendor all the tarballs'
+
+  # Remote environment (CI etc.)
+  > git clone https://.../myapp.git && cd myapp
+  > cpanm -L /path/to/lib --from $PWD/vendor/cache -nq --installdeps .
+
 =head1 HOW IT WORKS
 
 Carmel will keep the build directory (artifacts) after a cpanm
